GoogleMapsPlacesV1AddressDescriptor

Struct GoogleMapsPlacesV1AddressDescriptor 

pub struct GoogleMapsPlacesV1AddressDescriptor {
    pub areas: Option<Vec<GoogleMapsPlacesV1AddressDescriptorArea>>,
    pub landmarks: Option<Vec<GoogleMapsPlacesV1AddressDescriptorLandmark>>,
}
A relational description of a location. Includes a ranked set of nearby landmarks and precise containing areas and their relationship to the target location.

This type is not used in any activity, and only used as part of another schema.

Fields

areas: Option<Vec<GoogleMapsPlacesV1AddressDescriptorArea>>

A ranked list of containing or adjacent areas. The most recognizable and precise areas are ranked first.

landmarks: Option<Vec<GoogleMapsPlacesV1AddressDescriptorLandmark>>

A ranked list of nearby landmarks. The most recognizable and nearby landmarks are ranked first.