pub struct GoogleMapsPlacesV1AddressDescriptorArea {
pub containment: Option<String>,
pub display_name: Option<GoogleTypeLocalizedText>,
pub name: Option<String>,
pub place_id: Option<String>,
}Expand description
Area information and the area’s relationship with the target location. Areas includes precise sublocality, neighborhoods, and large compounds that are useful for describing a location.
This type is not used in any activity, and only used as part of another schema.
Fields
containment: Option<String>Defines the spatial relationship between the target location and the area.
display_name: Option<GoogleTypeLocalizedText>The area’s display name.
name: Option<String>The area’s resource name.
place_id: Option<String>The area’s place id.