GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText

Struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText 

pub struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText {
    pub matches: Option<Vec<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange>>,
    pub text: Option<String>,
}
Text representing a Place or query prediction. The text may be used as is or formatted.

This type is not used in any activity, and only used as part of another schema.

Fields

matches: Option<Vec<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange>>

A list of string ranges identifying where the input request matched in text. The ranges can be used to format specific parts of text. The substrings may not be exact matches of input if the matching was determined by criteria other than string matching (for example, spell corrections or transliterations). These values are Unicode character offsets of text. The ranges are guaranteed to be ordered in increasing offset values.

text: Option<String>

Text that may be used as is or formatted with matches.