pub struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction {
pub structured_format: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat>,
pub text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>,
}Expand description
Prediction results for a Query Autocomplete prediction.
This type is not used in any activity, and only used as part of another schema.
Fields
structured_format: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat>A breakdown of the query prediction into main text containing the query and secondary text containing additional disambiguating features (such as a city or region). structured_format is recommended for developers who wish to show two separate, but related, UI elements. Developers who wish to show a single UI element may want to use text instead. They are two different ways to represent a query prediction. Users should not try to parse structured_format into text or vice versa.
text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>The predicted text. This text does not represent a Place, but rather a text query that could be used in a search endpoint (for example, Text Search). text is recommended for developers who wish to show a single UI element. Developers who wish to show two separate, but related, UI elements may want to use structured_format instead. They are two different ways to represent a query prediction. Users should not try to parse structured_format into text or vice versa. May be in mixed languages if the request input and language_code are in different languages or if part of the query does not have a translation from the local language to language_code.