pub struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange {
pub end_offset: Option<i32>,
pub start_offset: Option<i32>,
}Expand description
Identifies a substring within a given text.
This type is not used in any activity, and only used as part of another schema.
Fields
end_offset: Option<i32>Zero-based offset of the last Unicode character (exclusive).
start_offset: Option<i32>Zero-based offset of the first Unicode character of the string (inclusive).