GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat

Struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat 

pub struct GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat {
    pub main_text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>,
    pub secondary_text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>,
}
Contains a breakdown of a Place or query prediction into main text and secondary text. For Place predictions, the main text contains the specific name of the Place. For query predictions, the main text contains the query. The secondary text contains additional disambiguating features (such as a city or region) to further identify the Place or refine the query.

This type is not used in any activity, and only used as part of another schema.

Fields

main_text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>

Represents the name of the Place or query.

secondary_text: Option<GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText>

Represents additional disambiguating features (such as a city or region) to further identify the Place or refine the query.