pub struct GoogleMapsPlacesV1ContentBlock {
pub content: Option<GoogleTypeLocalizedText>,
pub referenced_places: Option<Vec<String>>,
}Expand description
A block of content that can be served individually.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<GoogleTypeLocalizedText>Content related to the topic.
referenced_places: Option<Vec<String>>The list of resource names of the referenced places. This name can be used in other APIs that accept Place resource names.