GoogleMapsPlacesV1EVChargeOptions

Struct GoogleMapsPlacesV1EVChargeOptions 

pub struct GoogleMapsPlacesV1EVChargeOptions {
    pub connector_aggregation: Option<Vec<GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation>>,
    pub connector_count: Option<i32>,
}
Information about the EV Charge Station hosted in Place. Terminology follows https://afdc.energy.gov/fuels/electricity_infrastructure.html One port could charge one car at a time. One port has one or more connectors. One station has one or more ports.

This type is not used in any activity, and only used as part of another schema.

Fields

connector_aggregation: Option<Vec<GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation>>

A list of EV charging connector aggregations that contain connectors of the same type and same charge rate.

connector_count: Option<i32>

Number of connectors at this station. However, because some ports can have multiple connectors but only be able to charge one car at a time (e.g.) the number of connectors may be greater than the total number of cars which can charge simultaneously.