GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation

Struct GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation 

pub struct GoogleMapsPlacesV1EVChargeOptionsConnectorAggregation {
    pub availability_last_update_time: Option<DateTime<Utc>>,
    pub available_count: Option<i32>,
    pub count: Option<i32>,
    pub max_charge_rate_kw: Option<f64>,
    pub out_of_service_count: Option<i32>,
    pub type_: Option<String>,
}
EV charging information grouped by [type, max_charge_rate_kw]. Shows EV charge aggregation of connectors that have the same type and max charge rate in kw.

This type is not used in any activity, and only used as part of another schema.

Fields

availability_last_update_time: Option<DateTime<Utc>>

The timestamp when the connector availability information in this aggregation was last updated.

available_count: Option<i32>

Number of connectors in this aggregation that are currently available.

count: Option<i32>

Number of connectors in this aggregation.

max_charge_rate_kw: Option<f64>

The static max charging rate in kw of each connector in the aggregation.

out_of_service_count: Option<i32>

Number of connectors in this aggregation that are currently out of service.

type_: Option<String>

The connector type of this aggregation.