pub struct GoogleMapsPlacesV1Photo {
pub author_attributions: Option<Vec<GoogleMapsPlacesV1AuthorAttribution>>,
pub flag_content_uri: Option<String>,
pub google_maps_uri: Option<String>,
pub height_px: Option<i32>,
pub name: Option<String>,
pub width_px: Option<i32>,
}Expand description
Information about a photo of a place.
This type is not used in any activity, and only used as part of another schema.
Fields
This photo’s authors.
flag_content_uri: Option<String>A link where users can flag a problem with the photo.
google_maps_uri: Option<String>A link to show the photo on Google Maps.
height_px: Option<i32>The maximum available height, in pixels.
name: Option<String>Identifier. A reference representing this place photo which may be used to look up this place photo again (also called the API “resource” name: places/{place_id}/photos/{photo}).
width_px: Option<i32>The maximum available width, in pixels.