GoogleMapsPlacesV1PlaceAddressComponent

Struct GoogleMapsPlacesV1PlaceAddressComponent 

pub struct GoogleMapsPlacesV1PlaceAddressComponent {
    pub language_code: Option<String>,
    pub long_text: Option<String>,
    pub short_text: Option<String>,
    pub types: Option<Vec<String>>,
}
The structured components that form the formatted address, if this information is available.

This type is not used in any activity, and only used as part of another schema.

Fields

language_code: Option<String>

The language used to format this components, in CLDR notation.

long_text: Option<String>

The full text description or name of the address component. For example, an address component for the country Australia may have a long_name of “Australia”.

short_text: Option<String>

An abbreviated textual name for the address component, if available. For example, an address component for the country of Australia may have a short_name of “AU”.

types: Option<Vec<String>>

An array indicating the type(s) of the address component.