pub struct GoogleMapsPlacesV1PlaceConsumerAlert {
pub details: Option<GoogleMapsPlacesV1PlaceConsumerAlertDetails>,
pub language_code: Option<String>,
pub overview: Option<String>,
}Expand description
The consumer alert message for the place when we detect suspicious review activity on a business or a business violates our policies.
This type is not used in any activity, and only used as part of another schema.
Fields
details: Option<GoogleMapsPlacesV1PlaceConsumerAlertDetails>The details of the consumer alert message.
language_code: Option<String>The language code of the consumer alert message. This is a BCP 47 language code.
overview: Option<String>The overview of the consumer alert message.