pub struct GoogleMapsPlacesV1PlaceContainingPlace {
pub id: Option<String>,
pub name: Option<String>,
}Expand description
Info about the place in which this place is located.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The place id of the place in which this place is located.
name: Option<String>The resource name of the place in which this place is located.