pub struct GoogleMapsPlacesV1PlaceGenerativeSummary {
pub disclosure_text: Option<GoogleTypeLocalizedText>,
pub overview: Option<GoogleTypeLocalizedText>,
pub overview_flag_content_uri: Option<String>,
}Expand description
AI-generated summary of the place.
This type is not used in any activity, and only used as part of another schema.
Fields
disclosure_text: Option<GoogleTypeLocalizedText>The AI disclosure message “Summarized with Gemini” (and its localized variants). This will be in the language specified in the request if available.
overview: Option<GoogleTypeLocalizedText>The overview of the place.
overview_flag_content_uri: Option<String>A link where users can flag a problem with the overview summary.