pub struct GoogleMapsPlacesV1PlacePlusCode {
pub compound_code: Option<String>,
pub global_code: Option<String>,
}Expand description
Plus code (http://plus.codes) is a location reference with two formats: global code defining a 14mx14m (1/8000th of a degree) or smaller rectangle, and compound code, replacing the prefix with a reference location.
This type is not used in any activity, and only used as part of another schema.
Fields
compound_code: Option<String>Place’s compound code, such as “33GV+HQ, Ramberg, Norway”, containing the suffix of the global code and replacing the prefix with a formatted name of a reference entity.
global_code: Option<String>Place’s global (full) code, such as “9FWM33GV+HQ”, representing an 1/8000 by 1/8000 degree area (~14 by 14 meters).