pub struct GoogleMapsPlacesV1PlaceSubDestination {
pub id: Option<String>,
pub name: Option<String>,
}Expand description
Sub-destinations are specific places associated with a main place. These provide more specific destinations for users who are searching within a large or complex place, like an airport, national park, university, or stadium. For example, sub-destinations at an airport might include associated terminals and parking lots. Sub-destinations return the place ID and place resource name, which can be used in subsequent Place Details (New) requests to fetch richer details, including the sub-destination’s display name and location.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The place id of the sub-destination.
name: Option<String>The resource name of the sub-destination.