pub struct GoogleMapsPlacesV1RouteModifiers {
pub avoid_ferries: Option<bool>,
pub avoid_highways: Option<bool>,
pub avoid_indoor: Option<bool>,
pub avoid_tolls: Option<bool>,
}Expand description
Encapsulates a set of optional conditions to satisfy when calculating the routes.
This type is not used in any activity, and only used as part of another schema.
Fields
avoid_ferries: Option<bool>Optional. When set to true, avoids ferries where reasonable, giving preference to routes not containing ferries. Applies only to the DRIVE and TWO_WHEELER TravelMode.
avoid_highways: Option<bool>Optional. When set to true, avoids highways where reasonable, giving preference to routes not containing highways. Applies only to the DRIVE and TWO_WHEELER TravelMode.
avoid_indoor: Option<bool>Optional. When set to true, avoids navigating indoors where reasonable, giving preference to routes not containing indoor navigation. Applies only to the WALK TravelMode.
avoid_tolls: Option<bool>Optional. When set to true, avoids toll roads where reasonable, giving preference to routes not containing toll roads. Applies only to the DRIVE and TWO_WHEELER TravelMode.