GoogleMapsPlacesV1RoutingParameters

Struct GoogleMapsPlacesV1RoutingParameters 

pub struct GoogleMapsPlacesV1RoutingParameters {
    pub origin: Option<GoogleTypeLatLng>,
    pub route_modifiers: Option<GoogleMapsPlacesV1RouteModifiers>,
    pub routing_preference: Option<String>,
    pub travel_mode: Option<String>,
}
Parameters to configure the routing calculations to the places in the response, both along a route (where result ranking will be influenced) and for calculating travel times on results.

This type is not used in any activity, and only used as part of another schema.

Fields

origin: Option<GoogleTypeLatLng>

Optional. An explicit routing origin that overrides the origin defined in the polyline. By default, the polyline origin is used.

route_modifiers: Option<GoogleMapsPlacesV1RouteModifiers>

Optional. The route modifiers.

routing_preference: Option<String>

Optional. Specifies how to compute the routing summaries. The server attempts to use the selected routing preference to compute the route. The traffic aware routing preference is only available for the DRIVE or TWO_WHEELER travelMode.

travel_mode: Option<String>

Optional. The travel mode.