GoogleMapsPlacesV1SearchTextRequest

Struct GoogleMapsPlacesV1SearchTextRequest 

pub struct GoogleMapsPlacesV1SearchTextRequest {
Show 18 fields pub ev_options: Option<GoogleMapsPlacesV1SearchTextRequestEVOptions>, pub include_pure_service_area_businesses: Option<bool>, pub included_type: Option<String>, pub language_code: Option<String>, pub location_bias: Option<GoogleMapsPlacesV1SearchTextRequestLocationBias>, pub location_restriction: Option<GoogleMapsPlacesV1SearchTextRequestLocationRestriction>, pub max_result_count: Option<i32>, pub min_rating: Option<f64>, pub open_now: Option<bool>, pub page_size: Option<i32>, pub page_token: Option<String>, pub price_levels: Option<Vec<String>>, pub rank_preference: Option<String>, pub region_code: Option<String>, pub routing_parameters: Option<GoogleMapsPlacesV1RoutingParameters>, pub search_along_route_parameters: Option<GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters>, pub strict_type_filtering: Option<bool>, pub text_query: Option<String>,
}
Request proto for SearchText.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

ev_options: Option<GoogleMapsPlacesV1SearchTextRequestEVOptions>

Optional. Set the searchable EV options of a place search request.

include_pure_service_area_businesses: Option<bool>

Optional. Include pure service area businesses if the field is set to true. Pure service area business is a business that visits or delivers to customers directly but does not serve customers at their business address. For example, businesses like cleaning services or plumbers. Those businesses do not have a physical address or location on Google Maps. Places will not return fields including location, plus_code, and other location related fields for these businesses.

included_type: Option<String>

The requested place type. Full list of types supported: https://developers.google.com/maps/documentation/places/web-service/place-types. Only support one included type.

language_code: Option<String>

Place details will be displayed with the preferred language if available. If the language code is unspecified or unrecognized, place details of any language may be returned, with a preference for English if such details exist. Current list of supported languages: https://developers.google.com/maps/faq#languagesupport.

location_bias: Option<GoogleMapsPlacesV1SearchTextRequestLocationBias>

The region to search. This location serves as a bias which means results around given location might be returned. Cannot be set along with location_restriction.

location_restriction: Option<GoogleMapsPlacesV1SearchTextRequestLocationRestriction>

The region to search. This location serves as a restriction which means results outside given location will not be returned. Cannot be set along with location_bias.

max_result_count: Option<i32>

Deprecated: Use page_size instead. The maximum number of results per page that can be returned. If the number of available results is larger than max_result_count, a next_page_token is returned which can be passed to page_token to get the next page of results in subsequent requests. If 0 or no value is provided, a default of 20 is used. The maximum value is 20; values above 20 will be coerced to 20. Negative values will return an INVALID_ARGUMENT error. If both max_result_count and page_size are specified, max_result_count will be ignored.

min_rating: Option<f64>

Filter out results whose average user rating is strictly less than this limit. A valid value must be a float between 0 and 5 (inclusively) at a 0.5 cadence i.e. [0, 0.5, 1.0, … , 5.0] inclusively. The input rating will round up to the nearest 0.5(ceiling). For instance, a rating of 0.6 will eliminate all results with a less than 1.0 rating.

open_now: Option<bool>

Used to restrict the search to places that are currently open. The default is false.

page_size: Option<i32>

Optional. The maximum number of results per page that can be returned. If the number of available results is larger than page_size, a next_page_token is returned which can be passed to page_token to get the next page of results in subsequent requests. If 0 or no value is provided, a default of 20 is used. The maximum value is 20; values above 20 will be set to 20. Negative values will return an INVALID_ARGUMENT error. If both max_result_count and page_size are specified, max_result_count will be ignored.

page_token: Option<String>

Optional. A page token, received from a previous TextSearch call. Provide this to retrieve the subsequent page. When paginating, all parameters other than page_token, page_size, and max_result_count provided to TextSearch must match the initial call that provided the page token. Otherwise an INVALID_ARGUMENT error is returned.

price_levels: Option<Vec<String>>

Used to restrict the search to places that are marked as certain price levels. Users can choose any combinations of price levels. Default to select all price levels.

rank_preference: Option<String>

How results will be ranked in the response.

region_code: Option<String>

The Unicode country/region code (CLDR) of the location where the request is coming from. This parameter is used to display the place details, like region-specific place name, if available. The parameter can affect results based on applicable law. For more information, see https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html. Note that 3-digit region codes are not currently supported.

routing_parameters: Option<GoogleMapsPlacesV1RoutingParameters>

Optional. Additional parameters for routing to results.

search_along_route_parameters: Option<GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters>

Optional. Additional parameters proto for searching along a route.

strict_type_filtering: Option<bool>

Used to set strict type filtering for included_type. If set to true, only results of the same type will be returned. Default to false.

text_query: Option<String>

Required. The text query for textual search.