pub struct GoogleMapsPlacesV1SearchTextRequestEVOptions {
pub connector_types: Option<Vec<String>>,
pub minimum_charging_rate_kw: Option<f64>,
}Expand description
Searchable EV options of a place search request.
This type is not used in any activity, and only used as part of another schema.
Fields
connector_types: Option<Vec<String>>Optional. The list of preferred EV connector types. A place that does not support any of the listed connector types is filtered out.
minimum_charging_rate_kw: Option<f64>Optional. Minimum required charging rate in kilowatts. A place with a charging rate less than the specified rate is filtered out.