pub struct GoogleMapsPlacesV1SearchTextRequestLocationRestriction {
pub rectangle: Option<GoogleGeoTypeViewport>,
}Expand description
The region to search. This location serves as a restriction which means results outside given location will not be returned.
This type is not used in any activity, and only used as part of another schema.
Fields
rectangle: Option<GoogleGeoTypeViewport>A rectangle box defined by northeast and southwest corner. rectangle.high() must be the northeast point of the rectangle viewport. rectangle.low() must be the southwest point of the rectangle viewport. rectangle.low().latitude() cannot be greater than rectangle.high().latitude(). This will result in an empty latitude range. A rectangle viewport cannot be wider than 180 degrees.