pub struct GoogleTypeLocalizedText {
pub language_code: Option<String>,
pub text: Option<String>,
}Expand description
Localized variant of a text in a particular language.
This type is not used in any activity, and only used as part of another schema.
Fields
language_code: Option<String>The text’s BCP-47 language code, such as “en-US” or “sr-Latn”. For more information, see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
text: Option<String>Localized string in the language corresponding to language_code below.