PlaceGetCall

Struct PlaceGetCall 

pub struct PlaceGetCall<'a, C>
where C: 'a,
{ /* private fields */ }
Get the details of a place based on its resource name, which is a string in the places/{place_id} format.

A builder for the get method supported by a place resource. It is not used directly, but through a PlaceMethods instance.

Example

Instantiate a resource method builder




// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.places().get("name")
             .session_token("dolor")
             .region_code("ea")
             .language_code("ipsum")
             .doit().await;

Implementations

Source

impl<'a, C> PlaceGetCall<'a, C>
where C: Connector,

pub async fn doit(self) -> Result<(Response, GoogleMapsPlacesV1Place)>

Perform the operation you have build so far.

pub fn name(self, new_value: &str) -> PlaceGetCall<'a, C>

Required. The resource name of a place, in the places/{place_id} format.

Sets the name path property to the given value.

Even though the property as already been set when instantiating this call, we provide this method for API completeness.

pub fn session_token(self, new_value: &str) -> PlaceGetCall<'a, C>

Optional. A string which identifies an Autocomplete session for billing purposes. Must be a URL and filename safe base64 string with at most 36 ASCII characters in length. Otherwise an INVALID_ARGUMENT error is returned. The session begins when the user starts typing a query, and concludes when they select a place and a call to Place Details or Address Validation is made. Each session can have multiple queries, followed by one Place Details or Address Validation request. The credentials used for each request within a session must belong to the same Google Cloud Console project. Once a session has concluded, the token is no longer valid; your app must generate a fresh token for each session. If the session_token parameter is omitted, or if you reuse a session token, the session is charged as if no session token was provided (each request is billed separately). We recommend the following guidelines: * Use session tokens for all Place Autocomplete calls. * Generate a fresh token for each session. Using a version 4 UUID is recommended. * Ensure that the credentials used for all Place Autocomplete, Place Details, and Address Validation requests within a session belong to the same Cloud Console project. * Be sure to pass a unique session token for each new session. Using the same token for more than one session will result in each request being billed individually.

Sets the session token query property to the given value.

pub fn region_code(self, new_value: &str) -> PlaceGetCall<'a, C>

Optional. The Unicode country/region code (CLDR) of the location where the request is coming from. This parameter is used to display the place details, like region-specific place name, if available. The parameter can affect results based on applicable law. For more information, see https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html. Note that 3-digit region codes are not currently supported.

Sets the region code query property to the given value.

pub fn language_code(self, new_value: &str) -> PlaceGetCall<'a, C>

Optional. Place details will be displayed with the preferred language if available. Current list of supported languages: https://developers.google.com/maps/faq#languagesupport.

Sets the language code query property to the given value.

pub fn delegate(self, new_value: &'a mut dyn Delegate) -> PlaceGetCall<'a, C>

The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.

                  It should be used to handle progress information, and to implement a certain level of resilience.

Sets the delegate property to the given value.

pub fn param<T>(self, name: T, value: T) -> PlaceGetCall<'a, C>
where T: AsRef<str>,

Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.

Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.

Additional Parameters
  • $.xgafv (query-string) - V1 error format.
  • access_token (query-string) - OAuth access token.
  • alt (query-string) - Data format for response.
  • callback (query-string) - JSONP
  • fields (query-string) - Selector specifying which fields to include in a partial response.
  • key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
  • oauth_token (query-string) - OAuth 2.0 token for the current user.
  • prettyPrint (query-boolean) - Returns response with indentations and line breaks.
  • quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
  • uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
  • upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
pub fn add_scope<St>(self, scope: St) -> PlaceGetCall<'a, C>
where St: AsRef<str>,

Identifies the authorization scope for the method you are building.

Use this method to actively specify which scope should be used, instead of the default Scope variant Scope::CloudPlatform.

The scope will be added to a set of scopes. This is important as one can maintain access tokens for more than one scope.

Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.

pub fn add_scopes<I, St>(self, scopes: I) -> PlaceGetCall<'a, C>
where I: IntoIterator<Item = St>, St: AsRef<str>,

Identifies the authorization scope(s) for the method you are building.

See Self::add_scope() for details.

pub fn clear_scopes(self) -> PlaceGetCall<'a, C>

Removes all scopes, and no default scope will be used either. In this case, you have to specify your API-key using the key parameter (see Self::param() for details).