pub struct GoogleMapsPlacesV1AddressDescriptorLandmark {
pub display_name: Option<GoogleTypeLocalizedText>,
pub name: Option<String>,
pub place_id: Option<String>,
pub spatial_relationship: Option<String>,
pub straight_line_distance_meters: Option<f32>,
pub travel_distance_meters: Option<f32>,
pub types: Option<Vec<String>>,
}Expand description
Basic landmark information and the landmark’s relationship with the target location. Landmarks are prominent places that can be used to describe a location.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<GoogleTypeLocalizedText>The landmark’s display name.
name: Option<String>The landmark’s resource name.
place_id: Option<String>The landmark’s place id.
spatial_relationship: Option<String>Defines the spatial relationship between the target location and the landmark.
straight_line_distance_meters: Option<f32>The straight line distance, in meters, between the center point of the target and the center point of the landmark. In some situations, this value can be longer than travel_distance_meters.
travel_distance_meters: Option<f32>The travel distance, in meters, along the road network from the target to the landmark, if known. This value does not take into account the mode of transportation, such as walking, driving, or biking.
types: Option<Vec<String>>A set of type tags for this landmark. For a complete list of possible values, see https://developers.google.com/maps/documentation/places/web-service/place-types.