pub struct GoogleMapsPlacesV1FuelOptions {
pub fuel_prices: Option<Vec<GoogleMapsPlacesV1FuelOptionsFuelPrice>>,
}Expand description
The most recent information about fuel options in a gas station. This information is updated regularly.
This type is not used in any activity, and only used as part of another schema.
Fields
fuel_prices: Option<Vec<GoogleMapsPlacesV1FuelOptionsFuelPrice>>The last known fuel price for each type of fuel this station has. There is one entry per fuel type this station has. Order is not important.