pub struct GoogleMapsPlacesV1SearchTextResponse {
pub contextual_contents: Option<Vec<GoogleMapsPlacesV1ContextualContent>>,
pub next_page_token: Option<String>,
pub places: Option<Vec<GoogleMapsPlacesV1Place>>,
pub routing_summaries: Option<Vec<GoogleMapsPlacesV1RoutingSummary>>,
pub search_uri: Option<String>,
}Expand description
Response proto for SearchText.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- search text places (response)
Fields
contextual_contents: Option<Vec<GoogleMapsPlacesV1ContextualContent>>Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details. A list of contextual contents where each entry associates to the corresponding place in the same index in the places field. The contents that are relevant to the text_query in the request are preferred. If the contextual content is not available for one of the places, it will return non-contextual content. It will be empty only when the content is unavailable for this place. This list will have as many entries as the list of places if requested.
next_page_token: Option<String>A token that can be sent as page_token to retrieve the next page. If this field is omitted or empty, there are no subsequent pages.
places: Option<Vec<GoogleMapsPlacesV1Place>>A list of places that meet the user’s text search criteria.
routing_summaries: Option<Vec<GoogleMapsPlacesV1RoutingSummary>>A list of routing summaries where each entry associates to the corresponding place in the same index in the places field. If the routing summary is not available for one of the places, it will contain an empty entry. This list will have as many entries as the list of places if requested.
search_uri: Option<String>A link allows the user to search with the same text query as specified in the request on Google Maps.