pub struct PlaceMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on place resources.
It is not used directly, but through the MapsPlaces hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_places1 as places1;
use places1::{MapsPlaces, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = MapsPlaces::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `autocomplete(...)`, `get(...)`, `photos_get_media(...)`, `search_nearby(...)` and `search_text(...)`
// to build up your call.
let rb = hub.places();Implementations
Sourceimpl<'a, C> PlaceMethods<'a, C>
impl<'a, C> PlaceMethods<'a, C>
Sourcepub fn photos_get_media(&self, name: &str) -> PlacePhotoGetMediaCall<'a, C>
pub fn photos_get_media(&self, name: &str) -> PlacePhotoGetMediaCall<'a, C>
Create a builder to help you perform the following task:
Get a photo media with a photo reference string.
Arguments
name- Required. The resource name of a photo media in the format:places/{place_id}/photos/{photo_reference}/media. The resource name of a photo as returned in a Place object’sphotos.namefield comes with the formatplaces/{place_id}/photos/{photo_reference}. You need to append/mediaat the end of the photo resource to get the photo media resource name.
Sourcepub fn autocomplete(
&self,
request: GoogleMapsPlacesV1AutocompletePlacesRequest,
) -> PlaceAutocompleteCall<'a, C>
pub fn autocomplete( &self, request: GoogleMapsPlacesV1AutocompletePlacesRequest, ) -> PlaceAutocompleteCall<'a, C>
Create a builder to help you perform the following task:
Returns predictions for the given input.
Arguments
request- No description provided.
Sourcepub fn get(&self, name: &str) -> PlaceGetCall<'a, C>
pub fn get(&self, name: &str) -> PlaceGetCall<'a, C>
Create a builder to help you perform the following task:
Get the details of a place based on its resource name, which is a string in the places/{place_id} format.
Arguments
name- Required. The resource name of a place, in theplaces/{place_id}format.
Sourcepub fn search_nearby(
&self,
request: GoogleMapsPlacesV1SearchNearbyRequest,
) -> PlaceSearchNearbyCall<'a, C>
pub fn search_nearby( &self, request: GoogleMapsPlacesV1SearchNearbyRequest, ) -> PlaceSearchNearbyCall<'a, C>
Create a builder to help you perform the following task:
Search for places near locations.
Arguments
request- No description provided.
Sourcepub fn search_text(
&self,
request: GoogleMapsPlacesV1SearchTextRequest,
) -> PlaceSearchTextCall<'a, C>
pub fn search_text( &self, request: GoogleMapsPlacesV1SearchTextRequest, ) -> PlaceSearchTextCall<'a, C>
Create a builder to help you perform the following task:
Text query based place search.
Arguments
request- No description provided.