pub struct PlacePhotoGetMediaCall<'a, C>where
C: 'a,{ /* private fields */ }Expand description
Get a photo media with a photo reference string.
A builder for the photos.getMedia method supported by a place resource.
It is not used directly, but through a PlaceMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.places().photos_get_media("name")
.skip_http_redirect(true)
.max_width_px(-51)
.max_height_px(-12)
.doit().await;Implementations
Sourceimpl<'a, C> PlacePhotoGetMediaCall<'a, C>where
C: Connector,
impl<'a, C> PlacePhotoGetMediaCall<'a, C>where
C: Connector,
Sourcepub async fn doit(self) -> Result<(Response, GoogleMapsPlacesV1PhotoMedia)>
pub async fn doit(self) -> Result<(Response, GoogleMapsPlacesV1PhotoMedia)>
Perform the operation you have build so far.
Sourcepub fn name(self, new_value: &str) -> PlacePhotoGetMediaCall<'a, C>
pub fn name(self, new_value: &str) -> PlacePhotoGetMediaCall<'a, C>
Required. The resource name of a photo media in the format: places/{place_id}/photos/{photo_reference}/media. The resource name of a photo as returned in a Place object’s photos.name field comes with the format places/{place_id}/photos/{photo_reference}. You need to append /media at the end of the photo resource to get the photo media resource name.
Sets the name path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
Sourcepub fn skip_http_redirect(
self,
new_value: bool,
) -> PlacePhotoGetMediaCall<'a, C>
pub fn skip_http_redirect( self, new_value: bool, ) -> PlacePhotoGetMediaCall<'a, C>
Optional. If set, skip the default HTTP redirect behavior and render a text format (for example, in JSON format for HTTP use case) response. If not set, an HTTP redirect will be issued to redirect the call to the image media. This option is ignored for non-HTTP requests.
Sets the skip http redirect query property to the given value.
Sourcepub fn max_width_px(self, new_value: i32) -> PlacePhotoGetMediaCall<'a, C>
pub fn max_width_px(self, new_value: i32) -> PlacePhotoGetMediaCall<'a, C>
Optional. Specifies the maximum desired width, in pixels, of the image. If the image is smaller than the values specified, the original image will be returned. If the image is larger in either dimension, it will be scaled to match the smaller of the two dimensions, restricted to its original aspect ratio. Both the max_height_px and max_width_px properties accept an integer between 1 and 4800, inclusively. If the value is not within the allowed range, an INVALID_ARGUMENT error will be returned. At least one of max_height_px or max_width_px needs to be specified. If neither max_height_px nor max_width_px is specified, an INVALID_ARGUMENT error will be returned.
Sets the max width px query property to the given value.
Sourcepub fn max_height_px(self, new_value: i32) -> PlacePhotoGetMediaCall<'a, C>
pub fn max_height_px(self, new_value: i32) -> PlacePhotoGetMediaCall<'a, C>
Optional. Specifies the maximum desired height, in pixels, of the image. If the image is smaller than the values specified, the original image will be returned. If the image is larger in either dimension, it will be scaled to match the smaller of the two dimensions, restricted to its original aspect ratio. Both the max_height_px and max_width_px properties accept an integer between 1 and 4800, inclusively. If the value is not within the allowed range, an INVALID_ARGUMENT error will be returned. At least one of max_height_px or max_width_px needs to be specified. If neither max_height_px nor max_width_px is specified, an INVALID_ARGUMENT error will be returned.
Sets the max height px query property to the given value.
Sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> PlacePhotoGetMediaCall<'a, C>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> PlacePhotoGetMediaCall<'a, C>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.Sets the delegate property to the given value.
Sourcepub fn param<T>(self, name: T, value: T) -> PlacePhotoGetMediaCall<'a, C>
pub fn param<T>(self, name: T, value: T) -> PlacePhotoGetMediaCall<'a, C>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- $.xgafv (query-string) - V1 error format.
- access_token (query-string) - OAuth access token.
- alt (query-string) - Data format for response.
- callback (query-string) - JSONP
- fields (query-string) - Selector specifying which fields to include in a partial response.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
Sourcepub fn add_scope<St>(self, scope: St) -> PlacePhotoGetMediaCall<'a, C>
pub fn add_scope<St>(self, scope: St) -> PlacePhotoGetMediaCall<'a, C>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead of the default Scope variant
Scope::CloudPlatform.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.
Sourcepub fn add_scopes<I, St>(self, scopes: I) -> PlacePhotoGetMediaCall<'a, C>
pub fn add_scopes<I, St>(self, scopes: I) -> PlacePhotoGetMediaCall<'a, C>
Identifies the authorization scope(s) for the method you are building.
See Self::add_scope() for details.
Sourcepub fn clear_scopes(self) -> PlacePhotoGetMediaCall<'a, C>
pub fn clear_scopes(self) -> PlacePhotoGetMediaCall<'a, C>
Removes all scopes, and no default scope will be used either.
In this case, you have to specify your API-key using the key parameter (see Self::param()
for details).